@@ -1,4 +1,4 @@
-from typing import Tuple, Optional
+from typing import Optional, Tuple
 
 from django.conf import settings
 from django.db import models
@@ -59,10 +59,10 @@ class Source(GID, models.Model):
     updated_at = models.DateTimeField(auto_now=True)
 
     def __repr__(self):
-        return "{}".format(self.code)
+        return f"{self.code}"
 
     def __str__(self):
-        return "{}".format(self.code)
+        return f"{self.code}"
 
     def proceed(self, span, metric: 'Metric') -> Tuple[bool, Optional[int]]:
         from monitoring.plugins.sources import PLUGINS
@@ -71,7 +71,7 @@ class Source(GID, models.Model):
             raise Exception('Plugin not exists')
         try:
             return PLUGINS[erp_code].proceed(span, metric)
-        except Exception as e:
+        except Exception:
             return False, None
 
 
@@ -136,10 +136,10 @@ class Metric(GID, models.Model):
     updated_at = models.DateTimeField(auto_now=True)
 
     def __repr__(self):
-        return "{}".format(self.code)
+        return f"{self.code}"
 
     def __str__(self):
-        return "{}".format(self.code)
+        return f"{self.code}"
 
     def fire_alarm(self, span):
         if not self.is_active:
