@@ -1,10 +1,10 @@
-from typing import Tuple, Optional
+from collections import namedtuple
+from typing import Optional, Tuple
 
 from django.db import connection
 from shopcloud_django_instrumenting import tracing
 
 from monitoring import models
-from collections import namedtuple
 
 
 def dictfetchall(cursor):
