@@ -3,11 +3,11 @@ from inspect import getmembers, isfunction
 from django.test import TestCase
 from rest_framework import status
 from rest_framework.test import APIClient
+from shopcloud_django_instrumenting import tracing
 from shopcloud_django_toolbox import TestAdminTestCase
 from shopcloud_django_toolbox.tests import BaseTestApiAuthorization, SetupClass
-from shopcloud_django_instrumenting import tracing
 
-from . import seeds, models
+from . import models, seeds
 
 
 class TestAPIEndpointAuthorization(TestCase):
@@ -18,7 +18,7 @@ class TestAPIEndpointAuthorization(TestCase):
         ]
         client = APIClient()
         for x in urls:
-            r = client.get('/monitoring/api/{}/'.format(x))
+            r = client.get(f'/monitoring/api/{x}/')
             self.assertIn(r.status_code, [status.HTTP_403_FORBIDDEN, status.HTTP_302_FOUND])
 
 
@@ -51,7 +51,7 @@ class TestMetricAlarm(SetupClass):
         seeds.generate_metric()
 
         response = client.post(
-            f'/monitoring/api/metrics/cron/',
+            '/monitoring/api/metrics/cron/',
             data={},
             format='json'
         )
@@ -131,7 +131,7 @@ class TestMetricAlarm(SetupClass):
         is_fired = False
         try:
             metric.proceed(tracing.Tracer('service', 'operation'))
-        except Exception as e:
+        except Exception:
             is_fired = True
         self.assertEqual(is_fired, True)
 
@@ -200,7 +200,7 @@ class RepresentationTest(TestCase):
     def test_representations(self):
         members = getmembers(seeds, isfunction)
 
-        for name, func in [x for x in members if "generate" in x[0]]:
+        for _name, func in [x for x in members if "generate" in x[0]]:
             model = func()
             if model is not None:
                 model.__repr__()
